==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/TCPSocketActionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TCPSocketActionFluent<A extends io.fabric8.kubernetes.api.model.TCPSocketActionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getHost();
  public A withHost(java.lang.String host);
  public java.lang.Boolean hasHost();
  
  /**
   * Method is deprecated. use withHost instead.
   */
  @java.lang.Deprecated
  public A withNewHost(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getPort();
  public io.fabric8.kubernetes.api.model.IntOrString buildPort();
  public A withPort(io.fabric8.kubernetes.api.model.IntOrString port);
  public java.lang.Boolean hasPort();
  public A withNewPort(java.lang.Integer intVal);
  public A withNewPort(java.lang.String strVal);
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> withNewPort();
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> withNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editPort();
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editOrNewPort();
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editOrNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}

==> kubernetes-model-core-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/TCPSocketActionFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface TCPSocketActionFluent<A extends io.fabric8.kubernetes.api.model.TCPSocketActionFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getHost();
  public A withHost(java.lang.String host);
  public java.lang.Boolean hasHost();
  
  /**
   * Method is deprecated. use withHost instead.
   */
  @java.lang.Deprecated
  public A withNewHost(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getPort();
  public io.fabric8.kubernetes.api.model.IntOrString buildPort();
  public A withPort(io.fabric8.kubernetes.api.model.IntOrString port);
  public java.lang.Boolean hasPort();
  public A withNewPort(java.lang.Integer intVal);
  public A withNewPort(java.lang.String strVal);
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> withNewPort();
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> withNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editPort();
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editOrNewPort();
  public io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<A> editOrNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.kubernetes.api.model.TCPSocketActionFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  
}
